summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/variablewidget.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:24:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:24:21 -0600
commitabcbb684982167791304dc2fe0bc979489506b43 (patch)
treec705baa3702ffd62398873af8131525569b1af89 /languages/cpp/debugger/variablewidget.cpp
parent7e66d7c3611d907ea28b140281b472bb1c406be6 (diff)
downloadtdevelop-abcbb684982167791304dc2fe0bc979489506b43.tar.gz
tdevelop-abcbb684982167791304dc2fe0bc979489506b43.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'languages/cpp/debugger/variablewidget.cpp')
-rw-r--r--languages/cpp/debugger/variablewidget.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/languages/cpp/debugger/variablewidget.cpp b/languages/cpp/debugger/variablewidget.cpp
index bc598978..4abbe69b 100644
--- a/languages/cpp/debugger/variablewidget.cpp
+++ b/languages/cpp/debugger/variablewidget.cpp
@@ -988,7 +988,7 @@ void VariableTree::keyPressEvent(TQKeyEvent* e)
void VariableTree::copyToClipboard(TQListViewItem* item)
{
- TQClipboard *qb = KApplication::tqclipboard();
+ TQClipboard *qb = KApplication::clipboard();
TQString text = item->text( 1 );
qb->setText( text, TQClipboard::Clipboard );
@@ -1624,7 +1624,7 @@ void VarItem::updateSpecialRepresentation(const TQString& xs)
s = s.mid(i+2);
}
// A hack to nicely display TQStrings. The content of TQString is tqunicode
// for for ASCII only strings we get ascii character mixed with \000.
// Remove those \000 now.
@@ -1736,7 +1736,7 @@ bool VarItem::handleSpecialTypes()
else
varTree->controller()->addCommand(
new ValueSpecialRepresentationCommand(
- this, "print ($kdev_s>0) ? (*((char*)&$kdev_d.tqunicode[0])@$kdev_s) : \"\""));
+ this, "print ($kdev_s>0) ? (*((char*)&$kdev_d.unicode[0])@$kdev_s) : \"\""));
return true;
}
@@ -1853,7 +1853,7 @@ void VarItem::paintCell(TQPainter *p, const TQColorGroup &cg,
if (!alive_)
{
/* Draw this as disabled. */
- TQListViewItem::paintCell(p, varTree()->TQWidget::tqpalette().disabled(),
+ TQListViewItem::paintCell(p, varTree()->TQWidget::palette().disabled(),
column, width, align);
}
else
@@ -1624,7 +1624,7 @@ void VarItem::updateSpecialRepresentation(const TQString& xs)
s = s.mid(i+2);
}
- // A hack to nicely display TQStrings. The content of TQString is tqunicode
+ // A hack to nicely display TQStrings. The content of TQString is unicode
// for for ASCII only strings we get ascii character mixed with \000.
// Remove those \000 now.